@@ -1,8 +1,8 @@
 import logging
-import os
+from shutil import which
 
 from zygoat.components import Component
-from zygoat.constants import Phases, Projects, VENV
+from zygoat.constants import Phases, Projects
 from zygoat.utils.files import use_dir
 from zygoat.utils.shell import run
 
@@ -12,9 +12,9 @@ log = logging.getLogger()
 class Reformat(Component):
     def create(self):
         with use_dir(Projects.BACKEND):
-            black = os.path.join(VENV, "bin", "black")
-            if os.path.exists(black):
-                run([black, ".", "--exclude", VENV])
+            black = which("black")
+            if black is not None:
+                run([black, "."])
 
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
