@@ -24,10 +24,12 @@ class Cookies(SettingsComponent):
                 "\n",
                 "# Cookies",
                 "\n",
-                "SHARED_DOMAIN = env.str('DJANGO_SHARED_DOMAIN', default=None)",
+                "SHARED_DOMAIN = prod_required_env('DJANGO_SHARED_DOMAIN', default=None)",
                 "\n",
                 "CSRF_COOKIE_DOMAIN = SHARED_DOMAIN",
                 "\n",
+                "CSRF_TRUSTED_ORIGINS = SHARED_DOMAIN and [f'.{SHARED_DOMAIN}']",
+                "\n",
                 "SESSION_COOKIE_DOMAIN = SHARED_DOMAIN",
                 "\n",
                 "SESSION_ENGINE = 'django.contrib.sessions.backends.signed_cookies'",
